@@ -24,8 +24,8 @@ bool ldag::d_sep(const int& x, const int& y, const int& z) const {
   for (int i = 1; i <= n; i++) {
     if (in_set(i, x)) {
       dirvar x_el;
-      x_el.v = i;
       x_el.dir = true;
+      x_el.v = i;
       l.push(x_el);
     }
   }
@@ -34,9 +34,9 @@ bool ldag::d_sep(const int& x, const int& y, const int& z) const {
   while (!l.empty()) {
     is_visited = false;
     dirvar& l_el = l.top();
-    l.pop();
     d = l_el.dir;
     v = l_el.v;
+    l.pop();
     for (auto &vis : visited) {
       if (d == vis.dir && v == vis.v) {
         is_visited = true;
@@ -45,7 +45,10 @@ bool ldag::d_sep(const int& x, const int& y, const int& z) const {
     }
     if (!is_visited) {
       if (in_set(v, y)) return false;
-      visited.push_back(l_el);
+      dirvar vis_el;
+      vis_el.dir = d;
+      vis_el.v = v;
+      visited.push_back(vis_el);
       if (d && !in_set(v, z)) {
         visitable_parents(v, xyz, l);
         visitable_children(v, xyz, l);
@@ -80,8 +83,8 @@ void ldag::visitable_parents(const int& el, const int& xyz, std::stack<dirvar>&
   for (int i = 1; i <= n; i++) {
     if (edge(i, el) && in_set(i, xyz)) {
       dirvar pa_el;
-      pa_el.v = i;
       pa_el.dir = true;
+      pa_el.v = i;
       l.push(pa_el);
     }
   }
@@ -91,8 +94,8 @@ void ldag::visitable_children(const int& el, const int& xyz, std::stack<dirvar>&
   for (int i = 1; i <= n; i++) {
     if (edge(el, i) && in_set(i, xyz)) {
       dirvar ch_el;
-      ch_el.v = i;
       ch_el.dir = false;
+      ch_el.v = i;
       l.push(ch_el);
     }
   }
